# -*- coding: utf-8 -*-
from setuphelpers import *


appx_package_name = "Microsoft.LanguageExperiencePacken-GB"
appx_dir = makepath(programfiles, "WindowsAppsInstallers")
allow_remove = True
remove_sources = False  # remove_sources = True may prevent multi-user installations.


def install():
    # Declare local variables
    bins_dir = control.package.split("-", 1)[1]
    appx_bins_dir = makepath(appx_dir, bins_dir)

    # Remove from old path
    for appx_file in glob.glob(makepath(appx_dir, "%s_*" % appx_package_name)):
        remove_file(appx_file)

    # Placing bins for session-setup installs
    if isdir(appx_bins_dir):
        remove_tree(appx_bins_dir)
    mkdirs(appx_bins_dir)
    print(f"Creating: {appx_bins_dir}")
    for f in glob.glob(bins_dir + "/*"):
        filecopyto(f, appx_bins_dir)
    for f in glob.glob(appx_bins_dir + "/*"):
        fname = f.split(os.sep)[-1]
        if control.architecture == "all":
            if "x86" in glob.glob(makepath(appx_bins_dir, f"{appx_package_name}_*"))[0].split(os.sep)[-1]:
                if not "x86" in fname and not "neutral" in fname:
                    remove_file(f)
            else:
                if not get_host_architecture() in fname and not "neutral" in fname:
                    remove_file(f)
        else:
            if not get_host_architecture() in fname and not "neutral" in fname:
                remove_file(f)


def session_setup():
    # Declare local variables
    bins_dir = control.package.split("-", 1)[1]
    appx_bins_dir = makepath(appx_dir, bins_dir)

    # Installing the UWP application in the user environment
    try:
        appx_version = get_powershell_str(f'Get-AppxPackage -Name "{appx_package_name}"', "Version")
    except:
        appx_version = "0"
    if not appx_version or Version(appx_version) < Version(control.get_software_version()) or force:
        try:
            bin_path = glob.glob(makepath(appx_bins_dir, f"{appx_package_name}_*"))[0]
        except:
            error("Unable to find sources.\nPlease reinstall this package or change remove_sources to False if relevant.")
        dependencies_pathes = ",".join([f'"{a}"' for a in glob.glob(makepath(appx_bins_dir, "*")) if not appx_package_name in a])
        print("Installing: %s" % bin_path.split("\\")[-1])
        killalltasks(control.get_impacted_process_list())
        add_appx_cmd = f'Add-AppxPackage -Path "{bin_path}"'
        if dependencies_pathes:
            add_appx_cmd += f" -DependencyPath {dependencies_pathes}"
        run_powershell(add_appx_cmd)
    else:
        print(f"{appx_package_name} ({appx_version}) is installed and up-to-date")


def audit():
    bins_dir = control.package.split("-", 1)[1]
    appx_bins_dir = makepath(appx_dir, bins_dir)
    try:
        appx_version = get_powershell_str(f'Get-AppxPackage -Name "{appx_package_name}"', "Version")
        appx_installlocation = get_powershell_str(f'Get-AppxPackage -Name "{appx_package_name}"', "InstallLocation")
    except:
        appx_version = "0"
        appx_installlocation = "notfound"
    if dir_is_empty(appx_installlocation):
        print(f"Removing: {appx_bins_dir} since dir is empty")
    if isdir(appx_installlocation):
        if Version(appx_version) >= Version(control.get_software_version()):
            if remove_sources:
                print(f"Removing: {appx_bins_dir} since App is installed and up-to-date")
                remove_tree(appx_bins_dir)
            else:
                print(f"{appx_installlocation} is installed and up-to-date")
        else:
            print(f"{appx_installlocation} is installed but outdated")
    else:
        print(f"No user seems to have installed {appx_package_name} on this PC at the moment")

    return "OK"


def uninstall():
    # Declare local variables
    bins_dir = control.package.split("-", 1)[1]
    appx_bins_dir = makepath(appx_dir, bins_dir)

    if allow_remove:
        remove_appx(appx_package_name)
    if isdir(appx_bins_dir):
        print("Removing: %s" % (appx_bins_dir))
        remove_tree(appx_bins_dir)
    if dir_is_empty(appx_dir):
        print("Removing: %s since it is empty" % (appx_dir))
        remove_tree(appx_dir)
